********************************************
:mod:`mopidy.gstreamer` -- GStreamer adapter
********************************************

.. inheritance-diagram:: mopidy.gstreamer

.. automodule:: mopidy.gstreamer
    :synopsis: GStreamer adapter
    :members:
